(define-module (wkz-p1)
  #:use-module (rde features)
  #:use-module (rde features base)
  #:use-module (rde features documentation)
  #:use-module (rde features linux)
  #:use-module (rde features networking)
  #:use-module (rde features wm)
  #:use-module (rde features finance)
  #:use-module (rde features mail)
  #:use-module (rde features irc)
  #:use-module (rde features video)
  #:use-module (rde features keyboard)
  #:use-module (rde features fontutils)
  #:use-module (rde features emacs)
  #:use-module (rde features emacs-xyz)
  #:use-module (rde features shellutils)
  #:use-module (rde features terminals)
  #:use-module (rde features shells)
  #:use-module (rde features version-control)
  #:use-module (rde features virtualization)
  ;; #:use-module (rde features web)
  #:use-module (rde features xdg)
  #:use-module (gnu home-services base)
  #:use-module (gnu home services)
  #:use-module (gnu home-services wm)
  #:use-module (gnu services)

  #:use-module (rde packages)
  #:use-module (guix gexp))

(define home-extra-packages-service
  (simple-service
   'home-profile-extra-packages
   home-profile-service-type
   (append
    (strings->packages
     ;; "calibre"
     "glibc-locales"
     "icecat" ;; "nyxt"
     ;; "ungoogled-chromium-wayland" "ublock-origin-chromium"

     "alsa-utils" "pamixer" "yt-dlp"
     "pavucontrol" "wev"
     "imagemagick"
     "obs" "obs-wlrobs"
     "recutils" "binutils" "make"

     "papirus-icon-theme" "arc-theme"
     "thunar" "fd"
     "glib:bin"
     "wob" "brightnessctl"

     "ffmpeg"))))

(define sway-extra-config-service
  (simple-service
   'sway-extra-config
   home-sway-service-type
   `((output DP-2 scale 2)
     ,@(map (lambda (x) `(workspace ,x output DP-2)) (iota 8 1))

     (bindswitch --reload --locked lid:on exec /run/setuid-programs/swaylock)

     ;; Brightness control
     (bindsym --locked XF86MonBrightnessUp exec
              ,(file-append (@ (gnu packages linux) brightnessctl) "/bin/brightnessctl")
              set 5%+)
     (bindsym --locked XF86MonBrightnessDown exec
              ,(file-append (@ (gnu packages linux) brightnessctl) "/bin/brightnessctl")
              set 5%-)

     ;; Audio control
     (bindsym --locked XF86AudioLowerVolume exec
              ,(file-append (@ (gnu packages pulseaudio) pamixer) "/bin/pamixer")
              -ud 2)
     (bindsym --locked XF86AudioMute exec
              ,(file-append (@ (gnu packages pulseaudio) pamixer) "/bin/pamixer")
              --toggle-mute)

     (bindsym $mod+Ctrl+o focus output left)
     (input type:touchpad
            ((tap enabled)))

     ;; (xwayland disable)
     (bindsym $mod+Shift+Return exec emacs))))

(define minimal-rde-config
  (rde-config
   (features
    (list
     ;; %general-features
     (feature-user-info
      #:user-name "w96k"
      #:full-name "Mikhail Kirillov"
      #:email "w96k.ru@gmail.com"
      #:emacs-advanced-user? #t)

     (feature-vterm)
     (feature-bash)
     (feature-direnv)

     (feature-qemu)

     (feature-base-services)
     (feature-base-packages)

     (feature-desktop-services)
     (feature-hidpi)
     (feature-foreign-distro)
     
     (feature-sway)
     (feature-emacs
      #:default-application-launcher? #t)

     (feature-keyboard
    ;; To get all available options, layouts and variants run:
    ;; cat `guix build xkeyboard-config`/share/X11/xkb/rules/evdev.lst
    #:keyboard-layout
    (keyboard-layout
     "us,ru"
     "qwerty"
     #:options '("grp:shifts_toggle" "ctrl:nocaps")))

     ;; (feature-alternative-frontends)

     (feature-youtube-dl)

     (feature-emacs-appearance)
     ;; (feature-emacs-faces)
     (feature-emacs-modus-themes)

     (feature-emacs-completion
      #:mini-frame? #f
      #:marginalia-align 'right)
     (feature-emacs-corfu
      #:corfu-doc-auto #f)
     (feature-emacs-vertico)

     (feature-emacs-tramp)
     (feature-emacs-project)
     (feature-compile)
     (feature-emacs-perspective)
     (feature-emacs-input-methods)
     (feature-emacs-which-key)
     (feature-emacs-dired)
     (feature-emacs-eshell)
     (feature-emacs-monocle)

     (feature-emacs-message)
     ;; (feature-emacs-erc
     ;;  #:erc-log? #f
     ;;  #:erc-autojoin-channels-alist '((Libera.Chat "#rde")))
     (feature-emacs-telega)
     (feature-emacs-elpher)

     (feature-emacs-pdf-tools)
     ;; (feature-emacs-nov-el)
     (feature-emacs-org)
     (feature-emacs-org-roam
      #:org-roam-directory "~/projects/at-w96k/content/digarden/pages/"
     )
     (feature-emacs-org-agenda)
     (feature-emacs-org-protocol)
     ;; TODO: Remove auctex dependency, which interjects in texinfo-mode.
     ;; (feature-emacs-citar)

     (feature-emacs-smartparens
      #:show-smartparens? #t)

     (feature-emacs-pulseaudio-control)
     (feature-emacs-geiser)
     (feature-emacs-guix)
     (feature-emacs-eglot)

     (feature-manpages)

     (feature-xdg)

     (feature-git #:sign-commits? #f)

     (feature-custom-services
      #:feature-name-prefix 'w96k
      #:home-services
      (list
       home-extra-packages-service
       sway-extra-config-service
      ))

     ;; (feature-mpv
     ;;  #:extra-mpv-conf '((speed . 1.61)))

   (feature-sway-run-on-tty
    #:sway-tty-number 2)
   (feature-sway-screenshot)
   ;; (feature-sway-statusbar
   ;;  #:use-global-fonts? #f)
   (feature-waybar)
   (feature-swayidle)
   (feature-swaylock
    #:swaylock (@ (gnu packages wm) swaylock-effects)
    ;; The blur on lock screen is not privacy-friendly.
    #:extra-config '((screenshots)
                     (effect-blur . 7x5)
                     (clock)))
   ))))

(rde-config-home-environment minimal-rde-config)
